@@ -1,4 +1,4 @@
-# Copyright (C) 2008, Sebastian Riedel.
+# Copyright (C) 2008-2009, Sebastian Riedel.
 
 package Mojo::ByteStream;
 
@@ -172,7 +172,7 @@ sub quote {
     return $self;
 }
 
-sub to_string { return shift->{bytestream} }
+sub to_string { shift->{bytestream} }
 
 sub unquote {
     my $self = shift;
