@@ -16,9 +16,9 @@ require IO::File;
 use Mojo::ByteStream;
 use Mojo::Template;
 
-__PACKAGE__->attr(description => (default => 'No description.'));
-__PACKAGE__->attr(quiet       => (default => 0));
-__PACKAGE__->attr(renderer    => (default => sub { Mojo::Template->new }));
+__PACKAGE__->attr('description', default => 'No description.');
+__PACKAGE__->attr('quiet',       default => 0);
+__PACKAGE__->attr('renderer',    default => sub { Mojo::Template->new });
 
 sub chmod_file {
     my ($self, $path, $mod) = @_;
