@@ -9,7 +9,7 @@ use base 'Mojo::Server';
 
 use IO::Select;
 
-__PACKAGE__->attr(nph => (default => 0));
+__PACKAGE__->attr('nph', default => 0);
 
 # Lisa, you're a Buddhist, so you believe in reincarnation.
 # Eventually, Snowball will be reborn as a higher lifeform... like a snowman.
