@@ -12,11 +12,11 @@ use IO::Select;
 use IO::Socket;
 use Mojo::Pipeline;
 
-__PACKAGE__->attr(keep_alive_timeout      => (default => 15));
-__PACKAGE__->attr(listen_queue_size       => (default => SOMAXCONN));
-__PACKAGE__->attr(max_clients             => (default => 1000));
-__PACKAGE__->attr(max_keep_alive_requests => (default => 100));
-__PACKAGE__->attr(port                    => (default => 3000));
+__PACKAGE__->attr('keep_alive_timeout',      default => 15);
+__PACKAGE__->attr('listen_queue_size',       default => SOMAXCONN);
+__PACKAGE__->attr('max_clients',             default => 1000);
+__PACKAGE__->attr('max_keep_alive_requests', default => 100);
+__PACKAGE__->attr('port',                    default => 3000);
 
 sub accept_lock {1}
 
