@@ -11,9 +11,9 @@ use File::Spec;
 use MojoX::Types;
 
 __PACKAGE__->attr([qw/default_handler precedence/]);
-__PACKAGE__->attr(handler => (default => sub { {} }));
-__PACKAGE__->attr(types   => (default => sub { MojoX::Types->new }));
-__PACKAGE__->attr(root    => (default => '/'));
+__PACKAGE__->attr('handler', default => sub { {} });
+__PACKAGE__->attr('types',   default => sub { MojoX::Types->new });
+__PACKAGE__->attr('root',    default => '/');
 
 # This is not how Xmas is supposed to be.
 # In my day Xmas was about bringing people together, not blowing them apart.
