@@ -14,16 +14,15 @@ use MojoX::Dispatcher::Static;
 use MojoX::Types;
 use Time::HiRes ();
 
-__PACKAGE__->attr(ctx_class => (default => 'Mojolicious::Context'));
-__PACKAGE__->attr(
-    mode => (default => sub { ($ENV{MOJO_MODE} || 'development') }));
-__PACKAGE__->attr(
-    renderer => (default => sub { Mojolicious::Renderer->new }));
-__PACKAGE__->attr(
-    routes => (default => sub { MojoX::Dispatcher::Routes->new }));
-__PACKAGE__->attr(
-    static => (default => sub { MojoX::Dispatcher::Static->new }));
-__PACKAGE__->attr(types => (default => sub { MojoX::Types->new }));
+__PACKAGE__->attr('ctx_class', default => 'Mojolicious::Context');
+__PACKAGE__->attr('mode',
+    default => sub { ($ENV{MOJO_MODE} || 'development') });
+__PACKAGE__->attr('renderer', default => sub { Mojolicious::Renderer->new });
+__PACKAGE__->attr('routes',
+    default => sub { MojoX::Dispatcher::Routes->new });
+__PACKAGE__->attr('static',
+    default => sub { MojoX::Dispatcher::Static->new });
+__PACKAGE__->attr('types', default => sub { MojoX::Types->new });
 
 # The usual constructor stuff
 sub new {
@@ -37,7 +36,6 @@ sub new {
     $self->static->types($self->types);
 
     # Root
-    $self->home->detect(ref $self);
     $self->renderer->root($self->home->rel_dir('templates'));
     $self->static->root($self->home->rel_dir('public'));
 
@@ -97,9 +95,6 @@ sub dispatch {
     elsif ($e) { $self->static->serve_404($c) }
 }
 
-# This will run for every request after dispatch
-sub finalize { }
-
 # Bite my shiny metal ass!
 sub handler {
     my ($self, $tx) = @_;
@@ -107,17 +102,8 @@ sub handler {
     # Start timer
     my $start = [Time::HiRes::gettimeofday()];
 
-    # Context
-    my $c = $self->build_ctx($tx);
-
-    # Prepare
-    $self->prepare($c);
-
-    # Dispatch unless we already have a response code
-    $self->dispatch($c) unless $c->res->code;
-
-    # Finalize
-    $self->finalize($c);
+    # Build context and dispatch
+    $self->dispatch($self->build_ctx($tx));
 
     # End timer
     my $elapsed = sprintf '%f',
@@ -128,9 +114,6 @@ sub handler {
     return $tx;
 }
 
-# This will run for every request before dispatch
-sub prepare { }
-
 # This will run once at startup
 sub startup { }
 
@@ -221,18 +204,10 @@ For example in production mode, C<production_mode> will be called.
 
     $mojo->dispatch($c);
 
-=head2 C<finalize>
-
-    $mojo->finalize($c);
-
 =head2 C<handler>
 
     $tx = $mojo->handler($tx);
 
-=head2 C<prepare>
-
-    $mojo->prepare($c);
-
 =head2 C<startup>
 
     $mojo->startup($tx);
